@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,6 +86,14 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u043a\u044d\u043c\u044d",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Japan = new String[] {
                "\u0414\u044c\u043e\u043f\u043f\u0443\u043e\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
@@ -289,18 +297,10 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
         final Object[][] data = new Object[][] {
             { "Asia/Tokyo", Japan },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Asia/Aden", Arabian },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "Asia/Vladivostok", Vladivostok },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "timezone.excity.Asia/Irkutsk", "\u0418\u0440\u043a\u0443\u0442\u0441\u043a\u0430\u0439" },
@@ -313,66 +313,30 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a\u0430\u0439" },
             { "timezone.excity.Asia/Baghdad", "\u0411\u0430\u0433\u0434\u0430\u0430\u0434" },
             { "Asia/Yerevan", Armenia },
+            { "JST", Japan },
             { "timezone.excity.Asia/Srednekolymsk", "\u041e\u0440\u0442\u043e \u0425\u0430\u043b\u044b\u043c\u0430" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Kamchatka", "\u041a\u0430\u043c\u0447\u0430\u0430\u0442\u043a\u0430" },
+            { "NST", New_Zealand },
             { "Asia/Yakutsk", Yakutsk },
             { "timezone.excity.Asia/Samarkand", "\u0421\u0430\u043c\u0430\u0440\u043a\u0430\u0430\u043d" },
             { "timezone.excity.Asia/Yakutsk", "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439" },
             { "timezone.excity.Europe/Simferopol", "\u0421\u0438\u043c\u0444\u0435\u0440\u043e\u043f\u043e\u043b\u044c" },
             { "Asia/Tehran", Iran },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Omsk", "\u041e\u043c\u0441\u043a\u0430\u0439" },
             { "Antarctica/South_Pole", New_Zealand },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Australia/Adelaide", Australia_Central },
             { "timezone.excity.Asia/Chita", "\u0427\u0438\u0442\u0430\u0430" },
             { "timezone.excity.Asia/Colombo", "\u041a\u043e\u043b\u043e\u043c\u0431\u043e" },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "ACT", Australia_Central },
             { "Asia/Tbilisi", Georgia },
             { "Asia/Novosibirsk", Novosibirsk },
             { "timezone.excity.Asia/Anadyr", "\u0410\u043d\u0430\u0430\u0434\u044b\u0440" },
             { "timezone.excity.Asia/Ashgabat", "\u0410\u0441\u0445\u0430\u0431\u0430\u0430\u0442" },
             { "timezone.excity.Asia/Urumqi", "\u0423\u0440\u0443\u043c\u0447\u0443" },
+            { "NET", Armenia },
             { "timezone.excity.Asia/Barnaul", "\u0411\u0430\u0440\u043d\u0430\u0443\u043b" },
             { "timezone.excity.Asia/Sakhalin", "\u0421\u0430\u0445\u0430\u043b\u0438\u0438\u043d" },
             { "Asia/Riyadh", Arabian },
@@ -386,16 +350,6 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Qyzylorda", Kazakhstan_Eastern },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Chita", Yakutsk },
             { "timezone.excity.Asia/Krasnoyarsk", "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439" },
             { "Asia/Kuwait", Arabian },
@@ -404,18 +358,9 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "timezone.excity.Asia/Ust-Nera", "\u0423\u0443\u0441 \u041d\u044c\u0430\u0440\u0430" },
             { "timezone.excity.Asia/Damascus", "\u0414\u0430\u043c\u0430\u0430\u0441" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "timezone.excity.Asia/Choibalsan", "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d" },
+            { "AET", Australia_Eastern },
             { "timezone.excity.Asia/Baku", "\u0411\u0430\u043a\u0443\u0443" },
             { "timezone.excity.Europe/Moscow", "\u041c\u043e\u0441\u043a\u0443\u0431\u0430" },
             { "timezone.excity.Asia/Dubai", "\u0414\u0443\u0431\u0430\u0430\u0439" },
@@ -427,31 +372,12 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.Asia/Khandyga", "\u0425\u0430\u0430\u043d\u0434\u044b\u0433\u0430" },
             { "timezone.excity.Europe/Kaliningrad", "\u041a\u0430\u043b\u0438\u043d\u0438\u043d\u0433\u0440\u0430\u0434" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Australia/Currie", Australia_Eastern },
             { "Australia/Melbourne", Australia_Eastern },
             { "Asia/Bahrain", Arabian },
             { "timezone.excity.Asia/Kabul", "\u041a\u0430\u0431\u0443\u0443\u043b" },
             { "Asia/Chongqing", China },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "PLT", Pakistan },
             { "timezone.excity.Europe/Ulyanovsk", "\u0423\u043b\u044c\u044f\u043d\u043e\u0432\u0441\u043a\u0430\u0439" },
             { "Asia/Seoul", Korea },
             { "Australia/Sydney", Australia_Eastern },
